@@ -21,6 +21,7 @@
 
 #include <qapplication.h>
 #include <iostream>
+#include <cstdlib>
 
 #include <qptrlist.h>
 #include <qstring.h>
@@ -106,20 +107,6 @@ MythFlixConfig::MythFlixConfig(MythMainWindow *parent,
     connect(m_updateFreqTimer, SIGNAL(timeout()),
             this, SLOT(slotUpdateFreqTimerTimeout()));
 
-    // Create the database if not exists
-    QString queryString( "CREATE TABLE IF NOT EXISTS netflix "
-                         "( name VARCHAR(100) NOT NULL PRIMARY KEY,"
-                         "  category  VARCHAR(255) NOT NULL,"
-                         "  url  VARCHAR(255) NOT NULL,"
-                         "  ico  VARCHAR(255),"
-                         "  updated INT UNSIGNED,"
-                         "  is_queue INT UNSIGNED);");
-
-    MSqlQuery query(MSqlQuery::InitCon());
-
-    if (!query.exec(queryString))
-        VERBOSE(VB_IMPORTANT, QString("MythFlixConfig: Error in creating sql table"));
-
     m_Theme       = 0;
     m_UICategory  = 0;
     m_UISite      = 0;
@@ -132,6 +119,8 @@ MythFlixConfig::MythFlixConfig(MythMainWindow *parent,
 
     setNoErase();
     loadTheme();
+
+    updateBackground();
 }
 
 MythFlixConfig::~MythFlixConfig()
@@ -235,8 +224,6 @@ void MythFlixConfig::loadTheme()
                     m_SiteRect = area;
                 else if (name.lower() == "config-freq")
                     m_FreqRect = area;
-                else if (name.lower() == "config-bottom")
-                    m_BotRect = area;
             }
             else {
                 VERBOSE(VB_IMPORTANT, QString("MythFlix: Unknown element: %1").arg(e.tagName()));
@@ -302,13 +289,13 @@ void MythFlixConfig::loadTheme()
 
     ttype = (UITextType*)container->GetType("help");
     if (ttype) {
-        ttype->SetText(tr("Set update frequency by using the up/down arrows.\n"
+        ttype->SetText(tr("Set update frequency by using the up/down arrows."
                           "The minimum allowed value is 30 Minutes."));
     }
 
     ttype = (UITextType*)container->GetType("context_switch");
     if (ttype) {
-        ttype->SetText(tr("Press MENU to return to feed selection."));
+        ttype->SetText(tr("Press Escape or Menu to exit."));
     }
         
     connect(m_UICategory, SIGNAL(itemSelected(UIListBtnTypeItem*)),
@@ -321,11 +308,6 @@ void MythFlixConfig::loadTheme()
 void MythFlixConfig::paintEvent(QPaintEvent *e)
 {
     QRect r = e->rect();
-
-
-    if (r.intersects(m_BotRect)) {
-     //   updateBot();
-    }
     
     if (m_Context == 0) {
         if (r.intersects(m_SiteRect)) {
@@ -339,6 +321,24 @@ void MythFlixConfig::paintEvent(QPaintEvent *e)
     }
 }
 
+void MythFlixConfig::updateBackground(void)
+{
+    QPixmap bground(size());
+    bground.fill(this, 0, 0);
+
+    QPainter tmp(&bground);
+
+    LayerSet *container = m_Theme->GetSet("background");
+    if (container)
+    {
+        container->Draw(&tmp, 0, 0);
+    }
+
+    tmp.end();
+    m_background = bground;
+
+    setPaletteBackgroundPixmap(m_background);
+}
 
 void MythFlixConfig::updateSites()
 {
@@ -388,30 +388,6 @@ void MythFlixConfig::updateFreq()
            &pix, 0, 0, -1, -1, Qt::CopyROP);
 }
 
-void MythFlixConfig::updateBot()
-{
-    QPixmap pix(m_BotRect.size());
-    pix.fill(this, m_BotRect.topLeft());
-    QPainter p(&pix);
-    
-    LayerSet* container = m_Theme->GetSet("config-bottom");
-    if (container) {
-        container->Draw(&p, 0, 0);
-        container->Draw(&p, 1, 0);
-        container->Draw(&p, 2, 0);
-        container->Draw(&p, 3, 0);
-        container->Draw(&p, 4, 0);
-        container->Draw(&p, 5, 0);
-        container->Draw(&p, 6, 0);
-        container->Draw(&p, 7, 0);
-        container->Draw(&p, 8, 0);
-    }
-    p.end();
-    
-    bitBlt(this, m_BotRect.left(), m_BotRect.top(),
-           &pix, 0, 0, -1, -1, Qt::CopyROP);
-}
-
 void MythFlixConfig::toggleItem(UIListBtnTypeItem *item)
 {
     if (!item || !item->getData())
@@ -573,6 +549,10 @@ void MythFlixConfig::keyPressEvent(QKeyEvent *e)
         else if (action == "MENU") {
            changeContext();
         }
+        else if (action == "ESCAPE" && m_Context == 1)
+        {
+            changeContext();
+        }
         else if (action == "SELECT") {
             if (m_InColumn == 2 && m_Context == 0) {
                 UIListBtnTypeItem *item = m_UISite->GetItemCurrent();
