@@ -1,7 +1,7 @@
 #ifndef DBCHECK_H_
 #define DBCHECK_H_
 
-void UpgradePhoneDatabaseSchema(void);
+bool UpgradePhoneDatabaseSchema(void);
 
 #endif
 
