@@ -617,19 +617,23 @@ void PhoneUIBox::LoopbackButtonPushed()
 {
     if ((!loopbackMode) && (rtpAudio == 0) && (rtpVideo == 0))
     {
-        int loop = MythPopupBox::show2ButtonPopup(gContext->GetMainWindow(), "AskLoopback", "Loopback Audio and video at ...", "Socket on this machine", "NAT Device", 1);
+        DialogCode loop = MythPopupBox::Show2ButtonPopup(
+            gContext->GetMainWindow(),
+            "AskLoopback", tr("Loopback Audio and video at ..."),
+            tr("Socket on this machine"), tr("NAT Device"),
+            kDialogCodeButton0);
         QString loopIp;
         switch (loop)
         {
-        default:
-        case -1:
-            return;
-        case 0:
-            loopIp = sipStack->getLocalIpAddress();
-            break;
-        case 1:
-            loopIp = sipStack->getNatIpAddress();
-            break;
+            default:
+            case kDialogCodeRejected:
+                return;
+            case kDialogCodeButton0:
+                loopIp = sipStack->getLocalIpAddress();
+                break;
+            case kDialogCodeButton1:
+                loopIp = sipStack->getNatIpAddress();
+                break;
         }
         phoneUIStatusBar->DisplayCallState(QString(tr("Audio and Video Looped to ") + loopIp));
         int lvPort = atoi((const char *)gContext->GetSetting("VideoLocalPort"));
@@ -738,7 +742,7 @@ void PhoneUIBox::TransmitLocalWebcamImage()
                         cout << "SIP: Encoded H.323 frame size is " << encLen << "; too big for buffer\n";
                         rtpVideo->freeVideoBuffer(vb);
                     }
-                    else
+                    else if (encFrame && encLen >= 0)
                     {
                         memcpy(vb->video, encFrame, encLen); // Optimisation to get rid of this copy may be possible, check H.263 stack
                         vb->len = encLen;
@@ -750,6 +754,11 @@ void PhoneUIBox::TransmitLocalWebcamImage()
                             rtpVideo->freeVideoBuffer(vb);
                         }
                     }
+                    else
+                    {
+                        cout << "H263EncodeFrame returned -1\n";
+                        rtpVideo->freeVideoBuffer(vb);
+                    }
                 }
             }
             else
@@ -1030,11 +1039,11 @@ void PhoneUIBox::alertUser(QString callerUser, QString callerName, QString calle
         // Popup the caller's details
         closeCallPopup(); // Check we were not displaying one (e.g. user was getting ready to dial)
         if (entry)
-            doCallPopup(entry, "Answer", inAudioOnly);
+            doCallPopup(entry, tr("Answer"), inAudioOnly);
         else
         {
             DirEntry dummyEntry(callerDisplay, callerUrl, "", "", "");
-            doCallPopup(&dummyEntry, "Answer", inAudioOnly);
+            doCallPopup(&dummyEntry, tr("Answer"), inAudioOnly);
         }
     }
 }
@@ -1088,7 +1097,7 @@ void PhoneUIBox::doMenuPopup()
         menuPopup->addButton(tr("Delete all Voicemails"), this, SLOT(vmailEntryDeleteAll()));
         break;
     default:
-        delete menuPopup;
+        menuPopup->deleteLater();
         menuPopup = NULL;
         return;
         break;
@@ -1149,7 +1158,7 @@ void PhoneUIBox::menuHistorySave()
                                                   "\n\n" + QObject::tr("A directory entry already exists with this URL."));
                 NoDeviceDialog->AddButton(QObject::tr("OK"));
                 NoDeviceDialog->exec();
-                delete NoDeviceDialog;
+                NoDeviceDialog->deleteLater();
                 closeMenuPopup();
             }
             else
@@ -1271,8 +1280,7 @@ void PhoneUIBox::closeMenuPopup()
     if (!menuPopup)
         return;
 
-    menuPopup->hide();
-    delete menuPopup;
+    menuPopup->deleteLater();
     menuPopup = NULL;
 }
 
@@ -1317,8 +1325,7 @@ void PhoneUIBox::closeUrlPopup()
     if (!urlPopup)
         return;
 
-    urlPopup->hide();
-    delete urlPopup;
+    urlPopup->deleteLater();
     urlPopup = NULL;
 }
 
@@ -1416,8 +1423,7 @@ void PhoneUIBox::closeIMPopup()
     if (!imPopup)
         return;
 
-    imPopup->hide();
-    delete imPopup;
+    imPopup->deleteLater();
     imPopup = NULL;
 }
 
@@ -1552,8 +1558,7 @@ void PhoneUIBox::closeAddEntryPopup()
     if (!addEntryPopup)
         return;
 
-    addEntryPopup->hide();
-    delete addEntryPopup;
+    addEntryPopup->deleteLater();
     addEntryPopup = NULL;
 }
 
@@ -1644,8 +1649,7 @@ void PhoneUIBox::closeAddDirectoryPopup()
     if (!addDirectoryPopup)
         return;
 
-    addDirectoryPopup->hide();
-    delete addDirectoryPopup;
+    addDirectoryPopup->deleteLater();
     addDirectoryPopup = NULL;
 }
 
@@ -1716,7 +1720,7 @@ void PhoneUIBox::doCallPopup(DirEntry *entry, QString DialorAnswer, bool audioOn
         }
     
         QButton *button2=0;
-        if (DialorAnswer == "Dial")
+        if (DialorAnswer == tr("Dial"))
         {
             if (!audioOnly)
             {
@@ -1724,7 +1728,7 @@ void PhoneUIBox::doCallPopup(DirEntry *entry, QString DialorAnswer, bool audioOn
                 button1->setFocus();
             }
             button2 = incallPopup->addButton(DialorAnswer + tr(" Voice-Only"), this, SLOT(outcallDialVoiceSelected()));
-            incallPopup->addButton(tr("Send an Instant Message"), this, SLOT(incallSendIMSelected()));
+            incallPopup->addButton(tr("Send an Instant Message"), this, SLOT(outcallSendIMSelected()));
         }
         else
         {
@@ -1748,8 +1752,7 @@ void PhoneUIBox::closeCallPopup()
     if (!incallPopup)
         return;
 
-    incallPopup->hide();
-    delete incallPopup;
+    incallPopup->deleteLater();
     incallPopup = NULL;
 }
 
@@ -1914,8 +1917,7 @@ void PhoneUIBox::closeStatisticsPopup()
     if (!statsPopup)
         return;
 
-    statsPopup->hide();
-    delete statsPopup;
+    statsPopup->deleteLater();
     statsPopup = NULL;
     audioPkInOutLabel = audioPlayoutLabel = audioPkRtcpLabel = 0;
     videoResLabel = videoPkOutLabel = videoPkInLabel = videoPkRtcpLabel = videoFramesInOutDiscLabel = videoAvgFpsLabel = 0;
