@@ -9,16 +9,19 @@
  *       editor settings that define them.  For now, this file will contain
  *       settings slowly moved from config/conf.php and related files.
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/includes/config.php $
- * @date        $Date: 2006-06-24 14:03:10 -0500 (Sat, 24 Jun 2006) $
- * @version     $Revision: 10290 $
- * @author      $Author: xris $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/includes/config.php $
+ * @date        $Date: 2008-02-10 08:57:23 +0000 (Sun, 10 Feb 2008) $
+ * @version     $Revision: 15885 $
+ * @author      $Author: kormoc $
  * @license     GPL
  *
  * @package     MythWeb
  *
 /**/
 
+// Wipe out old/unused settings
+    $db->query('DELETE FROM settings WHERE value="WebVideo_URL"');  /** @todo:  Delete this line after 0.21 has been released */
+
 // Prefer channum over callsign?
     if (empty($_SESSION['prefer_channum']))
         $_SESSION['prefer_channum'] = setting('WebPrefer_Channum');
@@ -28,20 +31,18 @@
     if (!$_SESSION['date_statusbar'])       $_SESSION['date_statusbar']       = t('generic_date').', '.t('generic_time');
     if (!$_SESSION['date_scheduled'])       $_SESSION['date_scheduled']       = t('generic_date').' ('.t('generic_time').')';
     if (!$_SESSION['date_scheduled_popup']) $_SESSION['date_scheduled_popup'] = t('generic_date');
-    if (!$_SESSION['date_recorded'])        $_SESSION['date_recorded']        = t('generic_date').'<br />('.t('generic_time').')';
+    if (!$_SESSION['date_recorded'])        $_SESSION['date_recorded']        = t('generic_date').' ('.t('generic_time').')';
     if (!$_SESSION['date_search'])          $_SESSION['date_search']          = t('generic_date').', '.t('generic_time');
     if (!$_SESSION['date_listing_key'])     $_SESSION['date_listing_key']     = t('generic_date').', '.t('generic_time');
     if (!$_SESSION['date_listing_jump'])    $_SESSION['date_listing_jump']    = t('generic_date');
     if (!$_SESSION['date_channel_jump'])    $_SESSION['date_channel_jump']    = t('generic_date');
+    if (!$_SESSION['date_job_status'])      $_SESSION['date_job_status']      = t('generic_date').', '.t('generic_time');
     if (!$_SESSION['time_format'])          $_SESSION['time_format']          = t('generic_time');
 
 // Show pixmaps on the recorded programs page?
     if (!isset($_SESSION['recorded_pixmaps'])) {
          $_SESSION['recorded_pixmaps'] = (tmpl == 'default') ? true : false;
     }
-// height and width of generated pixmaps for recording thumbnails
-    define('video_img_width',  94);
-    define('video_img_height', 140);
 
 // Guide settings
     if (!isset($_SESSION['guide_favonly']))
@@ -50,7 +51,6 @@
 // The size of timeslots, in seconds (1800 = 30 minutes)
     if ($_SESSION['timeslot_size'] < 300) {
         switch (tmpl) {
-            case 'wml': $_SESSION['timeslot_size'] = 3600; break;
             case 'wap': $_SESSION['timeslot_size'] = 900;  break;
             default:    $_SESSION['timeslot_size'] = 300;  break;
         }
@@ -60,7 +60,6 @@
 // The number of time slots to display in the channel listing
     if ($_SESSION['num_time_slots'] < 3) {
         switch (tmpl) {
-            case 'wml': $_SESSION['num_time_slots'] = 1;  break;
             case 'wap': $_SESSION['num_time_slots'] = 12; break;
             default:    $_SESSION['num_time_slots'] = 36; break;
         }
@@ -91,22 +90,19 @@
 #######  Config below here has not yet been converted to session-configurable
 ###############################################################################
 
-/*
-    The following constants are used for the program listings page
-*/
+//  The following constants are used for the program listings page
 
-// Show mouseover information about programs?
-    define('show_popup_info', true);
+if (!isset($_SESSION['show_popup_info']))
+    $_SESSION['show_popup_info'] = 1;
 
-// show the channel icons?  true/false
-    define('show_channel_icons', true);
+if (!isset($_SESSION['show_channel_icons']))
+    $_SESSION['show_channel_icons'] = 1;
 
-// Sort channel list by channel nuber or by callsign?
-    define('sortby_channum', true);
+if (!isset($_SESSION['sortby_channum']))
+    $_SESSION['sortby_channum'] = 1;
 
-/*
-    The following constants are defined for the videos page
-*/
-    define('show_video_covers', true);
+// The following constants are defined for the videos page
 
+if (!isset($_SESSION['show_video_covers']))
+    $_SESSION['show_video_covers'] = 1;
 
