@@ -13,9 +13,9 @@
  * would like to inquire about the status of this arrangement, please contact
  * me personally.
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/includes/errors.php $
- * @date        $Date: 2006-06-24 14:03:10 -0500 (Sat, 24 Jun 2006) $
- * @version     $Revision: 10290 $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/includes/errors.php $
+ * @date        $Date: 2007-12-31 20:38:38 +0000 (Mon, 31 Dec 2007) $
+ * @version     $Revision: 15274 $
  * @author      $Author: xris $
  * @license     GPL
  *
@@ -101,7 +101,7 @@
             if ($errno != E_ASSERT_ERROR) {
                 echo "<hr><p><b>Fatal Error</b> at $errfile, line $errline:<br />$errstr</p>\n",
                      '<p>If you choose to ',
-                     '<b><u><a href="https://svn.mythtv.org/trac/newticket" target="_blank">submit a bug report</a></u></b>, ',
+                     '<b><u><a href="http://svn.mythtv.org/trac/newticket" target="_blank">submit a bug report</a></u></b>, ',
                      'please make sure to include a<br />',
                      'brief description of what you were doing, along with the following<br />',
                      'backtrace as an attachment (please don\'t paste the whole thing into<br />',
