@@ -5,9 +5,9 @@
  * It also uses the global variable $db, so it must be called from init.php
  * *after* the database connection has been established.
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/includes/session.php $
- * @date        $Date: 2006-06-24 14:03:10 -0500 (Sat, 24 Jun 2006) $
- * @version     $Revision: 10290 $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/includes/session.php $
+ * @date        $Date: 2007-12-31 20:38:38 +0000 (Mon, 31 Dec 2007) $
+ * @version     $Revision: 15274 $
  * @author      $Author: xris $
  * @license     GPL
  *
@@ -24,6 +24,12 @@
     session_set_save_handler('sess_do_nothing', 'sess_do_nothing', 'sess_read', 'sess_write', 'sess_destroy', 'sess_gc');
     session_start();
 
+// Register a destruction handler for the db object, since the guys who write
+// PHP are smoking something and think objects should be destroyed before the
+// sessions get written:  http://us2.php.net/session_set_save_handler
+    global $db;
+    $db->register_destruct_handler('session_write_close');
+
 /*
  *  The functions defined below are referenced above in session_set_save_handler()
 /*/
@@ -55,9 +61,11 @@
 /**/
     function sess_write($id, $data) {
         global $db;
+        if (empty($db))
+            return;
         if (!empty($_SERVER['REMOTE_USER']))
             $id = 'user:'.$_SERVER['REMOTE_USER'];
-        $db->query('REPLACE INTO mythweb_sessions (id, modified, data) VALUES(?,NULL,?)',
+        $db->query('REPLACE INTO mythweb_sessions (id, modified, data) VALUES (?,NULL,?)',
                    $id, $data);
         if (!$db->affected_rows())
             return false;
