@@ -3,10 +3,10 @@
  * The display code for the main welcome page that lists the available mythweb
  * sections.
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/_shared/tmpl/default/welcome.php $
- * @date        $Date: 2006-03-26 04:17:20 -0600 (Sun, 26 Mar 2006) $
- * @version     $Revision: 9494 $
- * @author      $Author: xris $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/_shared/tmpl/default/welcome.php $
+ * @date        $Date: 2008-02-10 02:36:08 +0000 (Sun, 10 Feb 2008) $
+ * @version     $Revision: 15879 $
+ * @author      $Author: kormoc $
  * @license     GPL
  *
  * @package     MythWeb
@@ -17,13 +17,13 @@
     $page_title = 'Welcome to MythWeb!';
 
 // Custom headers
-    $headers[] = '<link rel="stylesheet" type="text/css" href="'.skin_url.'/welcome.css" />';
+    $headers[] = '<link rel="stylesheet" type="text/css" href="'.skin_url.'/welcome.css">';
 
 // Print the page header
     require 'modules/_shared/tmpl/'.tmpl.'/header.php';
 ?>
 
-<script language="JavaScript" type="text/javascript">
+<script type="text/javascript">
 <!--
 
     var visible_module = 'tv';
@@ -31,11 +31,13 @@
         if (visible_module == module)
             return;
     // Change the outline on the list item
-        remove_class('module_' + visible_module, 'selected');
-        add_class('module_'    + module,         'selected');
+        $('module_'+ visible_module).removeClassName('selected');
+        $('module_'+ module).addClassName('selected');
     // Show and hide the appropriate info boxes
-        toggle_vis('info_' + visible_module);
-        toggle_vis('info_' + module);
+        $('info_' + visible_module).hide();
+        $('info_' + visible_module).addClassName('hidden');
+        $('info_' + module).show();
+        $('info_' + module).removeClassName('hidden');
     // Keep track of what's visible now
         visible_module = module;
     }
@@ -87,4 +89,3 @@
 <?php
 // Print the page footer
     require 'modules/_shared/tmpl/'.tmpl.'/footer.php';
-
