@@ -2,10 +2,10 @@
 /**
  * WAP header
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/_shared/tmpl/wap/header.php $
- * @date        $Date: 2006-09-30 00:46:38 -0500 (Sat, 30 Sep 2006) $
- * @version     $Revision: 11338 $
- * @author      $Author: xris $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/_shared/tmpl/wap/header.php $
+ * @date        $Date: 2008-01-18 07:55:58 +0000 (Fri, 18 Jan 2008) $
+ * @version     $Revision: 15489 $
+ * @author      $Author: kormoc $
  * @license     GPL
  *
  * @package     MythWeb
@@ -20,7 +20,7 @@
 <html>
 
 <head>
-    <title><?php echo htmlentities($page_title) ?></title>
+    <title><?php echo html_entities($page_title) ?></title>
     <Link Rel="stylesheet" HRef="<?php echo skin_url ?>style.css" Type="text/css" Media="screen">
     <Link Rel="stylesheet" HRef="<?php echo skin_url ?>handheld.css" Type="text/css" Media="handheld">
 </head>
@@ -39,6 +39,6 @@
 </center><br />
 <form action="<?php echo root ?>tv/search" method="get">
         <center><input type="text" name="s" value="<?php echo $_GET['s'] ?>"><br />
-        <input type="submit" class="submit" name="search" value="Search"></center><br />
+        <input type="submit" class="submit" name="search" value="<?php echo t('Search') ?>"></center><br />
 </form>
 
