@@ -3,9 +3,9 @@
  * The display code for the main welcome page that lists the available mythweb
  * sections.
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/backend_log/tmpl/default/backend_log.php $
- * @date        $Date: 2006-03-26 04:09:14 -0600 (Sun, 26 Mar 2006) $
- * @version     $Revision: 9493 $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/backend_log/tmpl/default/backend_log.php $
+ * @date        $Date: 2008-02-16 21:23:54 +0000 (Sat, 16 Feb 2008) $
+ * @version     $Revision: 16061 $
  * @author      $Author: xris $
  * @license     GPL
  *
@@ -17,7 +17,7 @@
     $page_title = 'MythTV - '.t('Backend Logs');
 
 // Custom headers
-    $headers[] = '<link rel="stylesheet" type="text/css" href="'.skin_url.'/backend_log.css" />';
+    $headers[] = '<link rel="stylesheet" type="text/css" href="'.skin_url.'/backend_log.css">';
 
 // Print the page header
     require 'modules/_shared/tmpl/'.tmpl.'/header.php';
@@ -47,4 +47,3 @@
 
 // Print the page footer
     require 'modules/_shared/tmpl/'.tmpl.'/footer.php';
-
