@@ -2,9 +2,9 @@
 /**
  * Initialization routines for the MythWeb Music module
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/music/init.php $
- * @date        $Date: 2006-09-15 00:08:12 -0500 (Fri, 15 Sep 2006) $
- * @version     $Revision: 11197 $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/music/init.php $
+ * @date        $Date: 2007-12-31 20:38:38 +0000 (Mon, 31 Dec 2007) $
+ * @version     $Revision: 15274 $
  * @author      $Author: xris $
  * @license     GPL
  *
@@ -21,10 +21,11 @@
     $db->error(false);
 
 // If music is enabled, add it to the list.
-    if ($has_music)
+    if ($has_music && tmpl == 'default') {
         $Modules['music'] = array('path'        => 'music',
                                   'sort'        => 2,
                                   'name'        => t('Music'),
                                   'description' => t('')
                                  );
+    }
 
