@@ -2,10 +2,10 @@
 /**
  * Welcome page description of the Music module.
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/music/tmpl/default/welcome.php $
- * @date        $Date: 2005-12-13 01:23:18 -0600 (Tue, 13 Dec 2005) $
- * @version     $Revision: 8252 $
- * @author      $Author: xris $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/music/tmpl/default/welcome.php $
+ * @date        $Date: 2008-02-10 02:36:08 +0000 (Sun, 10 Feb 2008) $
+ * @version     $Revision: 15879 $
+ * @author      $Author: kormoc $
  * @license     GPL
  *
  * @package     MythWeb
@@ -14,7 +14,7 @@
 
 // Open with a div and an image
     echo '<div id="info_music" class="hidden">',
-         '<img src="', skin_url, '/img/music.png" class="module_icon" />',
+         '<img src="', skin_url, '/img/music.png" class="module_icon" alt="">',
 
 // Print a basic overview of what this module does
          t('welcome: music'),
@@ -23,4 +23,4 @@
     ####
 
 // Close the div
-         "</div>\n";
\ No newline at end of file
+         "</div>\n";
