@@ -2,9 +2,9 @@
 /**
  * Mythweb recording stats.
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/stats/handler.php $
- * @date        $Date: 2006-04-06 21:53:45 -0500 (Thu, 06 Apr 2006) $
- * @version     $Revision: 9639 $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/stats/handler.php $
+ * @date        $Date: 2007-12-31 20:38:38 +0000 (Mon, 31 Dec 2007) $
+ * @version     $Revision: 15274 $
  * @author      $Author: xris $
  * @license     GPL
  *
@@ -68,17 +68,19 @@
                          .$where.' AND endtime > starttime');
 
 // Get the top ten recorded shows
-    $sh = $db->query('SELECT title, COUNT(programid) AS count, MAX(UNIX_TIMESTAMP(starttime)) AS last_recorded
+    $sh = $db->query('SELECT title,
+                      COUNT(programid)               AS recorded,
+		      MAX(UNIX_TIMESTAMP(starttime)) AS last_recorded
                         FROM oldrecorded '.$where
                  .' GROUP BY title
-                    ORDER BY count DESC, last_recorded, title '
+                    ORDER BY recorded DESC, last_recorded, title '
                     .$limit);
     while($row = $sh->fetch_assoc())
-        $top_ten_shows[] = $row;
+        $shows[] = $row;
     $sh->finish();
 
-// Get the top ten recorded shows
-    $sh = $db->query('SELECT COUNT(oldrecorded.chanid) as count,
+// Get the top recorded channels
+    $sh = $db->query('SELECT COUNT(oldrecorded.chanid) as recorded,
                              channel.name,
                              channel.channum,
                              MAX(UNIX_TIMESTAMP(oldrecorded.starttime)) as last_recorded
@@ -87,11 +89,11 @@
                                     ON channel.chanid = oldrecorded.chanid
                     '.$where.'
                              AND channel.channum IS NOT NULL
-                    GROUP BY oldrecorded.chanid
-                    ORDER BY count DESC, last_recorded, name '
+                    GROUP BY channel.callsign
+                    ORDER BY recorded DESC, last_recorded, name '
                     .$limit);
     while($row = $sh->fetch_assoc())
-        $top_ten_chans[] = $row;
+        $channels[] = $row;
     $sh->finish();
 
 // Print the stats page template
