@@ -2,10 +2,10 @@
 /**
  * Welcome page description of the status module.
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/stats/tmpl/default/welcome.php $
- * @date        $Date: 2006-03-26 16:26:24 -0600 (Sun, 26 Mar 2006) $
- * @version     $Revision: 9507 $
- * @author      $Author: xris $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/stats/tmpl/default/welcome.php $
+ * @date        $Date: 2008-02-10 02:36:08 +0000 (Sun, 10 Feb 2008) $
+ * @version     $Revision: 15879 $
+ * @author      $Author: kormoc $
  * @license     GPL
  *
  * @package     MythWeb
@@ -15,10 +15,10 @@
 
 // Open with a div and an image
     echo '<div id="info_stats" class="hidden">',
-         '<img src="', skin_url, '/img/stats.png" class="module_icon" />',
+         '<img src="', skin_url, '/img/stats.png" class="module_icon" alt="">',
 
 // Print a basic overview of what this module does
          t('welcome: stats'),
 
 // Close the div
-         "</div>\n";
\ No newline at end of file
+         "</div>\n";
