@@ -3,9 +3,9 @@
  * Should contain one variable, a hash of the 'advanced' searches.
  * Each of these searches will show up as an advanced search
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/tv/canned_searches.conf.php $
- * @date        $Date: 2006-06-28 14:19:22 -0500 (Wed, 28 Jun 2006) $
- * @version     $Revision: 10339 $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/tv/canned_searches.conf.php $
+ * @date        $Date: 2007-12-31 20:38:38 +0000 (Mon, 31 Dec 2007) $
+ * @version     $Revision: 15274 $
  * @author      $Author: xris $
  * @license     GPL
  *
@@ -40,11 +40,14 @@ $Canned_Searches = array(
         => 'category_type="movie" AND program.stars < 0.5625'
           .' AND program.stars > 0.0',
 
+    t('Childrens Movies')
+ 	    => 'category="children" AND category_type="movie"',
+
     t('Non-Series HDTV')
-        => 'hdtv=1 AND category_type != "series"',
+        => 'hdtv & 1 AND category_type != "series"',
 
     t('All HDTV')
-        => 'hdtv=1',
+        => 'hdtv & 1',
 
     t('Non-Music Specials')
         => 'showtype="special" AND program.category NOT LIKE "music%"',
