@@ -2,10 +2,10 @@
 /**
  * Handler for all MythWeb TV routines
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/tv/handler.php $
- * @date        $Date: 2006-06-14 01:50:09 -0500 (Wed, 14 Jun 2006) $
- * @version     $Revision: 10199 $
- * @author      $Author: xris $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/tv/handler.php $
+ * @date        $Date: 2008-03-08 00:05:53 +0000 (Sat, 08 Mar 2008) $
+ * @version     $Revision: 16433 $
+ * @author      $Author: kormoc $
  * @license     GPL
  *
  * @package     MythWeb
@@ -24,6 +24,12 @@
         exit;
     }
 
+// Call the opensearch module early, before loading all kinds of stuff it
+// doesn't need.  Plus, it's not "enabled" like other modules, so we skip that
+// check, too.
+    if ($Path[1] == 'opensearch')
+        require_once 'modules/tv/opensearch.php';
+
 /**
  * @global  array   $GLOBALS['Categories']
  * @name    $Categories
@@ -36,27 +42,42 @@
         load_tv_categories(modules_path.'/_shared/lang/'.$_SESSION['language'].'.cat');
     else
         load_tv_categories(modules_path.'/_shared/lang/English.cat');
-#    if (file_exists(modules_path.'/'.module.'/lang/'.$_SESSION['language'].'.cat'))
-#        load_tv_categories(modules_path.'/'.module.'/lang/'.$_SESSION['language'].'.cat');
-#    else
-#        load_tv_categories(modules_path.'/'.module.'/lang/English.cat');
 
 // Two categories that don't need regex matches, but do need translation
-    $Categories['Unknown'] = array(t('Unknown'));
-    $Categories['movie']   = array(t('movie'));
+//    $Categories['Unknown'] = array(t('Unknown'));
+//    $Categories['movie']   = array(t('movie'));
 
 // Don't forget to sort
-    ksort($Categories);
+    function category_name_sort($a, $b) {
+        return strnatcasecmp($a[0], $b[0]);
+    }
+    uasort($Categories, 'category_name_sort');
 
 // Load the tv-related libraries
-    require_once "includes/channels.php";
-    require_once "includes/programs.php";
-    require_once "includes/recording_schedules.php";
+    require_once 'includes/channels.php';
+    require_once 'includes/programs.php';
+    require_once 'includes/recording_schedules.php';
+
+// Restore the last used path?
+    if (empty($Path[1]) && is_array($_SESSION['tv']['last']))
+        array_splice($Path, 1, count($Path), $_SESSION['tv']['last']);
+
+// Flash player?
+    if (preg_match('/\.swf/', $Path[1])) {
+        header('Content-Type: application/x-shockwave-flash');
+        readfile('modules/tv/'.$Path[1]);
+        exit;
+    }
 
 // Unknown section?  Use the default
-    if (!in_array($Path[1], array('detail', 'channel', 'search', 'movies'))
-            && empty($Modules['tv']['links'][$Path[1]]))
+    if (!in_array($Path[1], array('recording_detail', 'detail', 'channel', 'search', 'movies', 'get_show_details'))
+            && empty($Modules['tv']['links'][$Path[1]])) {
         $Path[1] = 'list';
+    }
+
+// Keep track of this path for the next visit
+    if ($Path[1] != 'get_show_details')
+        $_SESSION['tv']['last'] = array_slice($Path, 1);
 
 // Show the requested section
     require_once 'modules/tv/'.$Path[1].'.php';
