@@ -2,9 +2,9 @@
 /**
  * Initialization routines for the MythWeb TV module.
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/tv/init.php $
- * @date        $Date: 2006-03-23 01:46:57 -0600 (Thu, 23 Mar 2006) $
- * @version     $Revision: 9478 $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/tv/init.php $
+ * @date        $Date: 2007-12-31 20:38:38 +0000 (Mon, 31 Dec 2007) $
+ * @version     $Revision: 15274 $
  * @author      $Author: xris $
  * @license     GPL
  *
@@ -13,6 +13,14 @@
  *
 /**/
 
+    $Settings['tv'] = array('name'    => t('TV'),
+                            'choices' => array('session'   => t('My Session'),
+                                               'channels'  => t('Channel Info'),
+                                               'playgroup' => t('Playback Groups'),
+                                              ),
+                            'default' => 'session',
+                           );
+
 // The TV module is always enabled.
     $Modules['tv'] = array('path'        => 'tv',
                            'sort'        => 1,
