@@ -2,10 +2,10 @@
 /**
  * view and manipulate recorded programs.
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/tv/recorded.php $
- * @date        $Date: 2006-07-04 14:36:23 -0500 (Tue, 04 Jul 2006) $
- * @version     $Revision: 10388 $
- * @author      $Author: xris $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/tv/recorded.php $
+ * @date        $Date: 2008-02-10 09:19:33 +0000 (Sun, 10 Feb 2008) $
+ * @version     $Revision: 15886 $
+ * @author      $Author: kormoc $
  * @license     GPL
  *
  * @package     MythWeb
@@ -16,70 +16,15 @@
 // Populate the $Channels array
     load_all_channels();
 
-// Make sure the recordings directory exists
-    if (file_exists('data/recordings')) {
-    // File is not a directory or a symlink
-        if (!is_dir('data/recordings') && !is_link('data/recordings')) {
-            custom_error('An invalid file exists at data/recordings.  Please remove it in'
-                        .' order to use the tv portions of MythWeb.');
-        }
-    }
-// Create the symlink, if possible.
-//
-// NOTE:  Errors have been disabled because if I turn them on, people hosting
-//        MythWeb on Windows machines will have issues.  I will turn the errors
-//        back on when I find a clean way to do so.
-//
-    else {
-        $dir = $db->query_col('SELECT data
-                                 FROM settings
-                                WHERE value="RecordFilePrefix" AND hostname=?',
-                              hostname
-                             );
-        if ($dir) {
-            $ret = @symlink($dir, 'data/recordings');
-            if (!$ret) {
-                #custom_error("Could not create a symlink to $dir, the local recordings directory"
-                #            .' for this hostname ('.hostname.').  Please create a symlink to your'
-                #            .' recordings directory at data/recordings in order to use the tv'
-                #            .' portions of MythWeb.');
-            }
-        }
-        else {
-            #custom_error('Could not find a value in the database for the recordings directory'
-            #            .' for this hostname ('.hostname.').  Please create a symlink to your'
-            #            .' recordings directory at data/recordings in order to use the tv'
-            #            .' portions of MythWeb.');
-        }
-    }
-
 // Load the sorting routines
-    require_once "includes/sorting.php";
+    require_once 'includes/sorting.php';
 
-// Auto-expire
-    isset($_GET['autoexpire']) or $_GET['autoexpire'] = $_POST['autoexpire'];
-    if (isset($_GET['autoexpire']) && $_GET['chanid'] && $_GET['starttime']) {
-        $sh = $db->query('UPDATE recorded
-                             SET autoexpire = ?
-                           WHERE chanid = ? AND starttime = FROM_UNIXTIME(?)',
-                         $_GET['autoexpire'] ? 1 : 0,
-                         $_GET['chanid'],
-                         $_GET['starttime']);
-    // Exit early if we're in AJAX mode.
-        if (isset($_GET['ajax'])) {
-            echo 'success';
-            exit;
-        }
-    }
-    else {
-        /** @todo need some sort of handler here for the non-ajax stuff */
-    }
-
-// Delete a program?
-    isset($_GET['forget_old']) or $_GET['forget_old'] = $_POST['forget_old'];
-    isset($_GET['delete'])     or $_GET['delete']     = $_POST['delete'];
-    isset($_GET['file'])       or $_GET['file']       = $_POST['file'];
-    if ($_GET['delete']) {
+// Delete or undelete a program?
+    if ($_REQUEST['delete'] || $_REQUEST['undelete']) {
+        if ($_REQUEST['delete'])
+          $backendstr = 'DELETE_RECORDING';
+        else
+          $backendstr = 'UNDELETE_RECORDING';
     // Keep a previous-row counter to return to after deleting
         $prev_row = -2;
     // We need to scan through the available recordings to get at the additional information required by the DELETE_RECORDING query
@@ -88,45 +33,38 @@
             if (($_SESSION['recorded_title'] == $row[0]) || ($_SESSION['recorded_title'] == ''))
                 $prev_row++;
         // This row isn't the one we're looking for
-            if ($row[4] != $_GET['chanid'] || $row[26] != $_GET['starttime'])
+            if ($row[4] != $_REQUEST['chanid'] || $row[26] != $_REQUEST['starttime'])
                 continue;
-        // Forget all knowledge of old recordings
-            if (isset($_GET['forget_old'])) {
-                $show = new Program($row);
-                $show->rec_forget_old();
-            // Delay a second so the backend can catch up
+        // Delete the recording
+            backend_command(array($backendstr, implode(backend_sep, $row), '0'));
+        // Forget all knowledge of old recordings?
+            if (isset($_REQUEST['forget_old'])) {
+                backend_command(array('FORGET_RECORDING', implode(backend_sep, $row), '0'));
+            // Delay a second so the scheduler can catch up
                 sleep(1);
             }
-        // Delete the recording
-            backend_command(array('DELETE_RECORDING', implode(backend_sep, $row), '0'));
         // Exit early if we're in AJAX mode.
-            if (isset($_GET['ajax'])) {
-                echo 'success';
+            if (isset($_REQUEST['ajax'])) {
+                header('Content-Type: application/json');
+                $JSON = new Services_JSON();
+                echo $JSON->encode(array('id'   => $_REQUEST['id'],
+                                         'file' => $_REQUEST['file']));
                 exit;
             }
         // No need to scan the rest of the items, so leave early
             break;
         }
     // Redirect back to the page again, but without the query string, so reloads are cleaner
-    // WML browser often require a fully qualified URL for redirects to work. Also, set content type
-        if ($_SESSION['Theme'] == 'wml') {
-            header('Content-type: text/vnd.wap.wml');
-            redirect_browser('http://'.$_SERVER['HTTP_HOST'].$_SERVER['SCRIPT_NAME'].'?refresh');
-        }
     // Return to the row just prior to the one deleted
     //  (with some fuzz to account for normal screen height
     //   -- remember that rows are numbered starting at zero)
-        else {
-            redirect_browser(root.'tv/recorded?refresh'.($prev_row > 0 ? "#$prev_row" : ''));
-        }
+        redirect_browser(root.'tv/recorded?refresh'.($prev_row > 0 ? "#$prev_row" : ''));
     // redirect_browser calls exit() on its own
     }
 
 // Queries for a specific program title
-    isset($_GET['title'])    or $_GET['title']    = $_POST['title'];
-    isset($_GET['recgroup']) or $_GET['recgroup'] = $_POST['recgroup'];
-    isset($_GET['title'])    or $_GET['title']    = isset($_GET['refresh']) ? '' : $_SESSION['recorded_title'];
-    isset($_GET['recgroup']) or $_GET['recgroup'] = isset($_GET['refresh']) ? '' : $_SESSION['recorded_recgroup'];
+    isset($_REQUEST['title'])    or $_REQUEST['title']    = isset($_REQUEST['refresh']) ? '' : $_SESSION['recorded_title'];
+    isset($_REQUEST['recgroup']) or $_REQUEST['recgroup'] = isset($_REQUEST['refresh']) ? '' : $_SESSION['recorded_recgroup'];
 
 // Parse the program list
     $warning    = NULL;
@@ -162,19 +100,19 @@
         // keep track of their names and how many episodes we have recorded
             $Total_Programs++;
             $Groups[$record[30]]++;
-        // Hide LiveTV recordings from the title list
-            if (($_GET['recgroup'] && $_GET['recgroup'] == $record[30]) || (!$_GET['recgroup'] && $record[30] != 'LiveTV'))
+        // Hide LiveTV  and Deleted recordings from the title list
+            if (($_REQUEST['recgroup'] && $_REQUEST['recgroup'] == $record[30]) || (!$_REQUEST['recgroup'] && $record[30] != 'LiveTV' && $record[30] != 'Deleted'))
                 $Program_Titles[$record[0]]++;
         // Skip files with no chanid
             if (!$record[4])
                 continue;
         // Skip programs the user doesn't want to look at
-            if ($_GET['title'] && $_GET['title'] != $record[0])
+            if ($_REQUEST['title'] && $_REQUEST['title'] != $record[0])
                 continue;
-            if ($_GET['recgroup'] && $_GET['recgroup'] != $record[30])
+            if ($_REQUEST['recgroup'] && $_REQUEST['recgroup'] != $record[30])
                 continue;
-        // Hide livetv recordings from the default view
-            if (empty($_GET['recgroup']) && $record[30] == 'LiveTV')
+        // Hide LiveTV recordings from the default view
+            if (empty($_REQUEST['recgroup']) && ($record[30] == 'LiveTV' || $record[30] == 'Deleted'))
                 continue;
         // Make sure that everything we're dealing with is an array
             if (!is_array($Programs[$record[0]]))
@@ -183,25 +121,25 @@
             $Programs[$record[0]][] = $record;
         }
     // Did we try to view a program that we don't have recorded?  Revert to showing all programs
-        if ($Total_Programs > 0 && !count($Programs) && !isset($_GET['refresh'])) {
+        if ($Total_Programs > 0 && !count($Programs) && !isset($_REQUEST['refresh'])) {
         // Requested the "All" mode, but there are no recordings
-            if (empty($_GET['title']) && empty($_GET['recgroup'])) {
+            if (empty($_REQUEST['title']) && empty($_REQUEST['recgroup'])) {
                 if ($Groups['LiveTV'] > 0) {
                     $warning = t('Showing all programs from the $1 group.', 'LiveTV');
-                    $_GET['recgroup'] = 'LiveTV';
+                    $_REQUEST['recgroup'] = 'LiveTV';
                     continue;
                 }
             }
         // Requested a title that's not in the requested group
-            if ($_GET['recgroup'] && $_GET['title'] && $Groups[$_GET['recgroup']] > 0) {
-                $warning = t('Showing all programs from the $1 group.', $_GET['recgroup']);
-                unset($_GET['title']);
+            if ($_REQUEST['recgroup'] && $_REQUEST['title'] && $Groups[$_REQUEST['recgroup']] > 0) {
+                $warning = t('Showing all programs from the $1 group.', $_REQUEST['recgroup']);
+                unset($_REQUEST['title']);
                 continue;
             }
         // Catch anything else
-            $_GET['refresh'] = true;
+            $_REQUEST['refresh'] = true;
             $warning         = t('Showing all programs.');
-            unset($_GET['title'], $_GET['recgroup']);
+            unset($_REQUEST['title'], $_REQUEST['recgroup']);
             continue;
         }
     // Did the best we could to find some programs; let's move on.
@@ -218,10 +156,6 @@
         foreach ($shows as $key => $record) {
         // Create a new program object
             $show =& new Program($record);
-        // Generate any thumbnail images we might need
-            if ($_SESSION['recorded_pixmaps']) {
-                generate_preview_pixmap($show);
-            }
         // Assign a reference to this show to the various arrays
             $All_Shows[]                         =& $show;
             $Programs[$title][$key]              =& $show;
@@ -235,8 +169,8 @@
     ksort($Groups);
 
 // Keep track of the program/title the user wants to view
-    $_SESSION['recorded_title']    = $_GET['title'];
-    $_SESSION['recorded_recgroup'] = $_GET['recgroup'];
+    $_SESSION['recorded_title']    = $_REQUEST['title'];
+    $_SESSION['recorded_recgroup'] = $_REQUEST['recgroup'];
 
 // The default sorting choice isn't so good for recorded programs, so we'll set our own default
     if (!is_array($_SESSION['recorded_sortby']) || !count($_SESSION['recorded_sortby']))
@@ -250,7 +184,7 @@
         sort_programs($All_Shows, 'recorded_sortby');
 
 // How much free disk space on the backend machine?
-    list($size_high, $size_low, $used_high, $used_low) = explode(backend_sep, backend_command('QUERY_FREE_SPACE'));
+    list($size_high, $size_low, $used_high, $used_low) = explode(backend_sep, backend_command('QUERY_FREE_SPACE_SUMMARY'));
     if (function_exists('gmp_add')) {
     // GMP functions should work better with 64 bit numbers.
         $size = gmp_mul('1024',
@@ -279,4 +213,3 @@
 
 // Exit
     exit;
-
