@@ -2,10 +2,10 @@
 /**
  * Schedule a custom recording by manually specifying various search options
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/tv/schedules_custom.php $
- * @date        $Date: 2006-06-24 14:03:10 -0500 (Sat, 24 Jun 2006) $
- * @version     $Revision: 10290 $
- * @author      $Author: xris $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/tv/schedules_custom.php $
+ * @date        $Date: 2008-02-16 21:50:50 +0000 (Sat, 16 Feb 2008) $
+ * @version     $Revision: 16069 $
+ * @author      $Author: kormoc $
  *
  * @package     MythWeb
  * @subpackage  TV
@@ -76,6 +76,8 @@
         // Set things as the user requested
             $schedule->profile       = $_POST['profile'];
             $schedule->recgroup      = $_POST['recgroup'];
+            $schedule->storagegroup  = $_POST['storagegroup'];
+            $schedule->playgroup     = $_POST['playgroup'];
             $schedule->autoexpire    = $_POST['autoexpire']   ? 1 : 0;
             $schedule->autocommflag  = $_POST['autocommflag'] ? 1 : 0;
             $schedule->autouserjob1  = $_POST['autouserjob1'] ? 1 : 0;
@@ -84,7 +86,7 @@
             $schedule->autouserjob4  = $_POST['autouserjob4'] ? 1 : 0;
             $schedule->inactive      = $_POST['inactive']     ? 1 : 0;
             $schedule->maxnewest     = $_POST['maxnewest']    ? 1 : 0;
-            $schedule->dupin         = _or($_POST['dupin'],    15);
+            $schedule->dupin         = _or($_POST['dupin'] + $_POST['dupin2'], dupsin_all);
             $schedule->dupmethod     = _or($_POST['dupmethod'], 6);
             $schedule->recpriority   = intval($_POST['recpriority']);
             $schedule->maxepisodes   = intval($_POST['maxepisodes']);
@@ -178,11 +180,13 @@
             mysql_free_result($result);
         }
     // autoexpire
-        if (!isset($schedule->autoexpire)) {
-            $result = mysql_query('SELECT data from settings where value="AutoExpireDefault"');
-            list($schedule->autoexpire) = mysql_fetch_row($result);
-            mysql_free_result($result);
-        }
+        if (!isset($schedule->autoexpire))
+            $schedule->autoexpire = get_backend_setting('AutoExpireDefault');
+    // start early / end late
+        if (!isset($schedule->startoffset))
+            $schedule->startoffset = get_backend_setting('DefaultStartOffset');
+        if (!isset($schedule->endoffset))
+            $schedule->endoffset = get_backend_setting('DefaultEndOffset');
     // Get the searchtype string
         switch ($schedule->search) {
             case searchtype_power:   $schedule->search_type = t('Power');   break;
@@ -201,6 +205,9 @@
     if ($schedule->length < 1)
         $schedule->length = 120;
 
+// Load the utility/display functions for scheduling
+    require_once 'includes/schedule_utils.php';
+
 // Load the class for this page
     require_once tmpl_dir.'schedules_custom.php';
 
@@ -239,14 +246,23 @@
             echo ' SELECTED';
         echo '>('.t('Any Channel').')</option>';
         foreach ($Channels as $channel) {
+        // Ignore invisible channels
+            if ($channel->visible == 0)
+                continue;
+        // Group by channum
+            if ($seen[$channel->channum])
+                continue;
+            $seen[$channel->channum] = $channel;
+
         // Print the option
-            echo '<option value="'.$channel->chanid.'"';
+            echo '<option value="', $channel->chanid, '"',
+                 ' title="', html_entities($channel->name), '"';
         // Selected?
             if ($channel->chanid == $chanid)
                 echo ' SELECTED';
         // Print ther est of the content
             echo '>';
-            if (prefer_channum)
+            if ($_SESSION["prefer_channum"])
                 echo $channel->channum.'&nbsp;&nbsp;('.html_entities($channel->callsign).')';
             else
                 echo html_entities($channel->callsign).'&nbsp;&nbsp;('.$channel->channum.')';
