@@ -2,10 +2,10 @@
 /**
  * Schedule a custom recording by manually specifying starttime and length
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/tv/schedules_manual.php $
- * @date        $Date: 2006-06-24 14:03:10 -0500 (Sat, 24 Jun 2006) $
- * @version     $Revision: 10290 $
- * @author      $Author: xris $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/tv/schedules_manual.php $
+ * @date        $Date: 2008-02-16 21:50:50 +0000 (Sat, 16 Feb 2008) $
+ * @version     $Revision: 16069 $
+ * @author      $Author: kormoc $
  *
  * @package     MythWeb
  * @subpackage  TV
@@ -60,37 +60,39 @@
     // Adding a new schedule
         else {
         // Set things as the user requested
-            $schedule->profile      = $_POST['profile'];
-            $schedule->recgroup     = $_POST['recgroup'];
-            $schedule->autoexpire   = $_POST['autoexpire']   ? 1 : 0;
-            $schedule->autocommflag = $_POST['autocommflag'] ? 1 : 0;
-            $schedule->autouserjob1 = $_POST['autouserjob1'] ? 1 : 0;
-            $schedule->autouserjob2 = $_POST['autouserjob2'] ? 1 : 0;
-            $schedule->autouserjob3 = $_POST['autouserjob3'] ? 1 : 0;
-            $schedule->autouserjob4 = $_POST['autouserjob4'] ? 1 : 0;
-            $schedule->maxnewest    = $_POST['maxnewest']    ? 1 : 0;
-            $schedule->dupin        = _or($_POST['dupin'],    15);
-            $schedule->dupmethod    = _or($_POST['dupmethod'], 6);
-            $schedule->recpriority  = intval($_POST['recpriority']);
-            $schedule->maxepisodes  = intval($_POST['maxepisodes']);
-            $schedule->startoffset  = intval($_POST['startoffset']);
-            $schedule->endoffset    = intval($_POST['endoffset']);
+            $schedule->profile       = $_POST['profile'];
+            $schedule->recgroup      = $_POST['recgroup'];
+            $schedule->storagegroup  = $_POST['storagegroup'];
+            $schedule->playgroup     = $_POST['playgroup'];
+            $schedule->autoexpire    = $_POST['autoexpire']   ? 1 : 0;
+            $schedule->autocommflag  = $_POST['autocommflag'] ? 1 : 0;
+            $schedule->autouserjob1  = $_POST['autouserjob1'] ? 1 : 0;
+            $schedule->autouserjob2  = $_POST['autouserjob2'] ? 1 : 0;
+            $schedule->autouserjob3  = $_POST['autouserjob3'] ? 1 : 0;
+            $schedule->autouserjob4  = $_POST['autouserjob4'] ? 1 : 0;
+            $schedule->maxnewest     = $_POST['maxnewest']    ? 1 : 0;
+            $schedule->dupin         = _or($_POST['dupin'] + $_POST['dupin2'], dupsin_all);
+            $schedule->dupmethod     = _or($_POST['dupmethod'], 6);
+            $schedule->recpriority   = intval($_POST['recpriority']);
+            $schedule->maxepisodes   = intval($_POST['maxepisodes']);
+            $schedule->startoffset   = intval($_POST['startoffset']);
+            $schedule->endoffset     = intval($_POST['endoffset']);
         // Some settings specific to manual recordings (since we have no program to match against)
-            $schedule->chanid      = $_POST['channel'];
-            $schedule->station     = $Channels[$schedule->chanid]->callsign;
-            $schedule->starttime   = strtotime($_POST['startdate'].' '.$_POST['starttime']);
-            $schedule->endtime     = $schedule->starttime + ($_POST['length'] * 60);
-            $schedule->description = 'Manually scheduled';
-            $schedule->category    = 'Manual recording';
-            $schedule->search      = searchtype_manual;
-            $schedule->findday     = date('w',     $schedule->starttime);
-            $schedule->findtime    = date('H:m:s', $schedule->starttime);
+            $schedule->chanid        = $_POST['channel'];
+            $schedule->station       = $Channels[$schedule->chanid]->callsign;
+            $schedule->starttime     = strtotime($_POST['startdate'].' '.$_POST['starttime']);
+            $schedule->endtime       = $schedule->starttime + ($_POST['length'] * 60);
+            $schedule->description   = 'Manually scheduled';
+            $schedule->category      = 'Manual recording';
+            $schedule->search        = searchtype_manual;
+            $schedule->findday       = date('w',     $schedule->starttime);
+            $schedule->findtime      = date('H:m:s', $schedule->starttime);
             $schedule->autotranscode = $_POST['autotranscode'] ? 1 : 0;
-            $schedule->transcoder  = $_POST['transcoder'];
+            $schedule->transcoder    = $_POST['transcoder'];
         // Figure out the title
             $channel = $Channels[$_POST['channel']];
             if (strcasecmp($_POST['title'], t('Use callsign')) == 0) {
-                if (prefer_channum)
+                if ($_SESSION["prefer_channum"])
                     $schedule->title = $channel->channum.' ('.$channel->callsign.')';
                 else
                     $schedule->title = $channel->callsign.' ('.$channel->channum.')';
@@ -160,6 +162,9 @@
     if ($schedule->length < 1)
         $schedule->length = 120;
 
+// Load the utility/display functions for scheduling
+    require_once 'includes/schedule_utils.php';
+
 // Load the class for this page
     require_once tmpl_dir.'schedules_manual.php';
 
@@ -183,13 +188,14 @@
             $seen[$channel->channum] = $channel;
 
         // Print the option
-            echo '<option value="'.$channel->chanid.'"';
+            echo '<option value="', $channel->chanid, '"',
+                 ' title="', html_entities($channel->name), '"';
         // Selected?
             if ($channel->chanid == $chanid)
                 echo ' SELECTED';
         // Print ther est of the content
             echo '>';
-            if (prefer_channum)
+            if ($_SESSION["prefer_channum"])
                 echo $channel->channum.'&nbsp;&nbsp;('.html_entities($channel->callsign).')';
             else
                 echo html_entities($channel->callsign).'&nbsp;&nbsp;('.$channel->channum.')';
