@@ -9,9 +9,9 @@
  *
  *   Use ^ and/or $ to anchor the search, and enclose in // to use regex.
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/tv/search.php $
- * @date        $Date: 2006-08-31 00:49:58 -0500 (Thu, 31 Aug 2006) $
- * @version     $Revision: 11002 $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/tv/search.php $
+ * @date        $Date: 2008-03-07 02:28:17 +0000 (Fri, 07 Mar 2008) $
+ * @version     $Revision: 16421 $
  * @author      $Author: xris $
  * @license     GPL
  *
@@ -204,7 +204,7 @@
             }
         // HDTV only?
             if ($_SESSION['search']['hd'])
-                $extra_query[] = 'program.hdtv=1';
+                $extra_query[] = 'program.hdtv & 1';
         // Commercial-free channels only?
             if ($_SESSION['search']['commfree'])
                 $extra_query[] = 'channel.commfree=1';
@@ -231,6 +231,9 @@
                             case 'category':
                                 $query .= 'program.category';
                                 break;
+                            case 'people':
+                                $query .= 'people.name';
+                                break;
                             case 'channum':
                                 $query .= 'channel.channum';
                                 break;
@@ -269,10 +272,10 @@
             $search_str = $_SESSION['search']['s'];
         // If it starts with hd: it's an hd-only search
             if (preg_match('/^hd:\s*(.+)$/', $search_str, $match)) {
-                $extra_query[] = 'program.hdtv=1';
+                $extra_query[] = 'program.hdtv & 1';
                 $search_str    = $match[1];
             }
-        // If The next thing starts with stars, it's a movie rating query
+        // If the next thing starts with stars, it's a movie rating query
             if (preg_match('#(\\*+\s*(1/2\b|0?\.5\b|-)?)\s*(.*?)$#', $search_str, $match)) {
                 $starcount = substr_count($match[1], '*') / 4;
                 if (preg_match('/1\\/2|\\.5|-/', $match[1]))
@@ -286,10 +289,16 @@
             $extra_query[] = 'program.endtime >= NOW()';
         // Build the query
             list($compare, $search) = prep_search($search_str);
-            $query[] = "program.title       $compare $search";
-            $query[] = "program.subtitle    $compare $search";
-            $query[] = "program.description $compare $search";
-            $query[] = "program.category    $compare $search";
+            if (empty($_REQUEST['field']) || preg_match('/\btitle/i', $_REQUEST['field']))
+                $query[] = "program.title       $compare $search";
+            if (empty($_REQUEST['field']) || stristr($_REQUEST['field'], 'subtitle'))
+                $query[] = "program.subtitle    $compare $search";
+            if (empty($_REQUEST['field']) || stristr($_REQUEST['field'], 'desc'))
+                $query[] = "program.description $compare $search";
+            if (empty($_REQUEST['field']) || stristr($_REQUEST['field'], 'cat'))
+                $query[] = "program.category    $compare $search";
+            if (empty($_REQUEST['field']) || stristr($_REQUEST['field'], 'people'))
+                $query[] = "people.name         $compare $search";
             $query   = implode(' OR ', $query);
         }
 
@@ -317,14 +326,23 @@
 // Build a list of titles for figuring out alternate showings.  Use the same
 // key to make parsing things below a little easier.
     $titles = array();
+    $seen = array();
     foreach ($Results as $key => $show) {
-        $titles[$show->title.': '.$show->subtitle][$key] =& $Results[$key];
+        $tkey = md5($show->channel->channum.':'.$show->channel->callsign.':'.$show->title.':'.$show->subtitle.':'.$show->description);
+        $skey = $show->channel->name.$show->starttime.$tkey;
+        if($seen[$skey]){
+            unset($Results[$key]);
+            continue;
+        }else{
+            $titles[$tkey][$key] =& $Results[$key];
+            $seen[$skey] = true;
+        }
     }
 
 // Parse the show list for showings that can be consolidated/folded
     $seen = array();
     foreach ($Results as $key => $show) {
-        $tkey = $show->title.': '.$show->subtitle;
+        $tkey = md5($show->channel->channum.':'.$show->channel->callsign.':'.$show->title.':'.$show->subtitle.':'.$show->description);
     // Populate extra_showings info for other instances of this show
         if (count($titles[$tkey]) > 1) {
             foreach (array_keys($titles[$tkey]) as $key2) {
@@ -413,6 +431,7 @@
                                    'subtitle'    => html_entities(t('Subtitle')),
                                    'description' => html_entities(t('Description')),
                                    'category'    => html_entities(t('Category')),
+                                   'people'      => html_entities(t('People')),
                                    'channum'     => html_entities(t('Chan. Number')),
                                    'channame'    => html_entities(t('Chan. Name')),
                                    'callsign'    => html_entities(t('Chan. Callsign')),
@@ -460,7 +479,7 @@
                 echo '</select>';
             }
             echo ' <a id="add_search_field_', $i, '" onclick="add_search_field(', $i, ')">', t('more'), '...</a>',
-                 "<br />\n",
+                 "<br>\n",
                  t('matches'), ': <input type="text" size="35" name="as[', $i, ']" id="as', $i, '" value="',
                  html_entities($string), "\" onchange=\"set_search('a')\">\n";
         }
@@ -484,7 +503,7 @@
                      ' to ',
                      movie_star_select('stars_lt');
             }
-            echo '<br />';
+            echo '<br>';
         }
     }
 
