@@ -3,9 +3,9 @@
  * This file defines a theme class for the all recordings section.
  * It must define one method.   documentation will be added someday.
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/tv/tmpl/default/schedules.php $
- * @date        $Date: 2006-06-24 14:03:10 -0500 (Sat, 24 Jun 2006) $
- * @version     $Revision: 10290 $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/tv/tmpl/default/schedules.php $
+ * @date        $Date: 2008-02-16 21:10:09 +0000 (Sat, 16 Feb 2008) $
+ * @version     $Revision: 16059 $
  * @author      $Author: xris $
  *
  * @package     MythWeb
@@ -17,7 +17,7 @@
     $page_title = 'MythWeb - '.t('Recording Schedules');
 
 // Custom headers
-    $headers[] = '<link rel="stylesheet" type="text/css" href="'.skin_url.'/tv_schedules.css" />';
+    $headers[] = '<link rel="stylesheet" type="text/css" href="'.skin_url.'/tv_schedules.css">';
 
 // Print the page header
     require 'modules/_shared/tmpl/'.tmpl.'/header.php';
@@ -25,11 +25,9 @@
 
 // No schedules defined?
     if (!is_array($the_schedules) || !count($the_schedules)) {
-?>
-<div id="no_schedules" class="command command_border_l command_border_t command_border_b command_border_r">
-<?php       echo t('No recording schedules have been defined.') ?>
-</div>
-<?php
+        echo '<div id="no_schedules">',
+             t('No recording schedules have been defined.').
+             '</div>';
         return;
     }
 
@@ -39,16 +37,17 @@
         $group_field = '';
 ?>
 
-<table id="listings" width="100%" border="0" cellpadding="4" cellspacing="2" class="list small">
+<table id="listings" border="0" cellpadding="4" cellspacing="2" class="list small">
 <tr class="menu">
     <?php if ($group_field != '') echo "<td class=\"list\">&nbsp;</td>\n" ?>
-    <td><?php echo get_sort_link('title',    t('title')) ?></td>
-    <td><?php echo get_sort_link('recpriority', t('recpriority')) ?></td>
-    <td><?php echo get_sort_link(prefer_channum ? 'channum' : 'callsign',  t('channel')) ?></td>
-    <td><?php echo get_sort_link('profile',  t('profile')) ?></td>
-    <td><?php echo get_sort_link('transcoder',  t('transcoder')) ?></td>
-    <td><?php echo get_sort_link('recgroup', t('recgroup')) ?></td>
-    <td><?php echo get_sort_link('type',     t('type')) ?></td>
+    <th class="x-title"><?php      echo get_sort_link('title',                                  t('Title'))                  ?></th>
+    <th class="x-priority"><?php   echo get_sort_link('recpriority',                            t('Recording Priority'))     ?></th>
+    <th class="x-channel"><?php    echo get_sort_link($_SESSION["prefer_channum"] ? 'channum' : 'callsign',  t('Channel'))   ?></th>
+    <th class="x-profile"><?php    echo get_sort_link('profile',                                t('Profile'))                ?></th>
+    <th class="x-transcoder"><?php echo get_sort_link('transcoder',                             t('Transcoder'))             ?></th>
+    <th class="x-group"><?php      echo get_sort_link('recgroup',                               t('Recording Group'))        ?></th>
+    <th class="x-type"><?php       echo get_sort_link('type',                                   t('Type'))                   ?></th>
+    <th class="x-sgroup"><?php     echo get_sort_link('storagegroup',                           t('Storage Group'))          ?></th>
 </tr><?php
         $prev_group = '';
         $cur_group  = '';
@@ -56,12 +55,12 @@
         // Reset the command variable to a default URL
             $urlstr = 'recordid='.$schedule->recordid;
 
-            $class = ($schedule->type == rectype_dontrec ? 'deactivated' : 'scheduled');
+            $css_class = ($schedule->type == rectype_dontrec ? 'deactivated' : 'scheduled');
         // If this is an 'always on any channel' or 'find one' recording w/o a channel, set the channel name to 'Any'
             if ($schedule->type == rectype_always || ($schedule->type == rectype_findone && !preg_match('/\\S/', $schedule->channel->channum)))
                 $schedule->channel->name = '[ '.t('Any').' ]';
         // A program id counter for popup info
-            if (show_popup_info) {
+            if ($_SESSION["show_popup_info"]) {
                 static $program_id_counter = 0;
                 $program_id_counter++;
             }
@@ -75,10 +74,12 @@
                 $cur_group = $schedule->profile;
             elseif ($group_field == 'recgroup')
                 $cur_group = $schedule->recgroup;
+            elseif ($group_field == 'storagegroup')
+                $cur_group = $schedule->storagegroup;
         // "none"?
             $cur_group or $cur_group = t('None');
 
-            $style_class = $schedule->class;
+            $style_class = $schedule->css_class;
             if ($schedule->type == rectype_override)
                 $style_class .= ' record_override_record';
             elseif ($schedule->type == rectype_dontrec)
@@ -90,17 +91,15 @@
 </tr><?php
             }
         // Print the content
-    ?><tr class="<?php echo $class ?>">
+    ?><tr class="<?php echo $css_class ?>">
         <?php if ($group_field != '') echo "<td class=\"list\">&nbsp;</td>\n" ?>
-    <td class="<?php echo $style_class ?>"><?php
+    <td class="x-title <?php echo $style_class ?>"><?php
         // Window status text, for the mouseover
             $wstatus = "Details for $schedule->title";
         // Print a link to the program detail for this schedule
             echo '<a';
-            if (show_popup_info)
+            if ($_SESSION["show_popup_info"])
                 echo show_popup("program_$program_id_counter", $schedule->details_list(), NULL, 'popup', $wstatus);
-            else
-                echo " onmouseover=\"wstatus('".str_replace('\'', '\\\'', $wstatus)."');return true\" onmouseout=\"wstatus('');return true\"";
             echo ' href="'.root.'tv/';
         // Link to different places for different kinds of schedules
             if ($schedule->search) {
@@ -117,11 +116,11 @@
                 echo ":  $schedule->subtitle";
             echo '</a>';
         ?></td>
-    <td><?php
+    <td class="x-priority"><?php
             echo $schedule->recpriority
         ?></td>
-    <td><?php
-            if (prefer_channum) {
+    <td class="x-channel"><?php
+            if ($_SESSION["prefer_channum"]) {
                 if ($schedule->channel->channum)
                     echo $schedule->channel->channum.' - ';
             }
@@ -131,15 +130,14 @@
             }
             echo $schedule->channel->name;
         ?></td>
-    <td nowrap><?php echo _or($schedule->profile,  '&nbsp;') ?></td>
-    <td nowrap>
-        <?php
+    <td class="x-profile"><?php echo _or($schedule->profile,  '&nbsp;') ?></td>
+    <td class="x-transcoder"><?php
         global $Transcoders;
         echo _or($Transcoders[$schedule->transcoder],  '&nbsp;')
-        ?>
-    </td>
-    <td nowrap><?php echo _or($schedule->recgroup, '&nbsp;') ?></td>
-    <td nowrap><?php echo $schedule->texttype ?></td>
+        ?></td>
+    <td class="x-group"><?php echo _or($schedule->recgroup, '&nbsp;') ?></td>
+    <td class="x-type"><?php  echo $schedule->texttype ?></td>
+    <td class="x-group"><?php echo _or($schedule->storagegroup, '&nbsp;') ?></td>
 </tr><?php
             $prev_group = $cur_group;
         }
@@ -150,4 +148,3 @@
 
 // Print the page footer
     require 'modules/_shared/tmpl/'.tmpl.'/footer.php';
-
