@@ -2,9 +2,9 @@
 /**
  * Show search results, or how to perform a detailed search.
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/tv/tmpl/default/search.php $
- * @date        $Date: 2006-08-31 00:49:58 -0500 (Thu, 31 Aug 2006) $
- * @version     $Revision: 11002 $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/tv/tmpl/default/search.php $
+ * @date        $Date: 2008-02-16 21:10:09 +0000 (Sat, 16 Feb 2008) $
+ * @version     $Revision: 16059 $
  * @author      $Author: xris $
  * @license     GPL
  *
@@ -17,7 +17,7 @@
     $page_title = 'MythWeb - '.t('Search');
 
 // Custom headers
-    #$headers[] = '<link rel="stylesheet" type="text/css" href="'.skin_url.'/tv_search.css" />';
+    $headers[] = '<link rel="stylesheet" type="text/css" href="'.skin_url.'/tv_search.css">';
 
 // Print the page header
     require 'modules/_shared/tmpl/'.tmpl.'/header.php';
@@ -25,7 +25,7 @@
 // Print the advanced search options
 ?>
 
-<script language="JavaScript" type="text/javascript">
+<script type="text/javascript">
 <!--
 
     function search_field_change(i) {
@@ -42,46 +42,47 @@
     }
 
     function set_search(type) {
-        get_element('type_' + type).checked = true;
+        $('type_' + type).checked = true;
     }
 
 // -->
 </script>
 
 <form class="form" id="search_advanced" action="<?php echo root ?>tv/search" method="get">
-    <input type="hidden" name="type" value="a">
+    <div><input type="hidden" name="type" value="a"></div>
 
-<table align="center" border="1" cellspacing="0" cellpadding="2" class="command command_border_l command_border_t command_border_b command_border_r">
+<table id="search_options" border="0" cellspacing="0" cellpadding="0" class="commandbox commands">
 <tr>
-    <td valign="top"><?php print_advanced_search_strings() ?>
-        </td>
-    <td valign="top"><p style="margin-top: 0">
+    <td class="x-advanced"><?php
+        print_advanced_search_strings()
+        ?></td>
+    <td class="x-timeopts"><p style="margin-top: 0">
         <input type="checkbox" name="hd" id="hd" value="1"<?php
             if ($_SESSION['search']['hd']) echo ' CHECKED' ?>>
         <label for="hd"><?php echo t('Only match HD programs') ?></label>
-        <br />
+        <br>
         <input type="checkbox" name="commfree" id="commfree" value="1"<?php
             if ($_SESSION['search']['commfree']) echo ' CHECKED' ?>>
         <label for="commfree"><?php echo t('Only match commercial-free channels') ?></label>
         </p>
         <p>
-        Showings between:<br />
+        <?php echo t('Showings between'); ?>:<br>
         <input type="text" size="12" name="starttime" style="text-align: center" value="<?php echo html_entities($_SESSION['search']['starttime']) ?>">
-        and
+        <?php echo t('and'); ?>
         <input type="text" size="12" name="endtime"   style="text-align: center" value="<?php echo html_entities($_SESSION['search']['endtime']) ?>">
         </p>
         <p>
-        Originally aired between:<br />
+        <?php echo t('Originally aired between'); ?>:<br>
         <input type="text" size="12" name="airdate_start" style="text-align: center" value="<?php echo html_entities($_SESSION['search']['airdate_start']) ?>">
-        and
+        <?php echo t('and'); ?>
         <input type="text" size="12" name="airdate_end" style="text-align: center" value="<?php echo html_entities($_SESSION['search']['airdate_end']) ?>">
         </p>
         </td>
-    <td valign="top">Program Type:<br />
+    <td class="x-progtype"><?php echo t('Program Type'); ?>:<br>
         <?php echo category_type_list() ?>
         </td>
-    <td valign="middle">
-        <input type="submit" name="search" value="Search" style="margin: 10px">
+    <td class="x-submit">
+        <input type="submit" class="submit" name="search" value="<?php echo t('Search') ?>">
         </td>
 </tr>
 </table>
@@ -93,7 +94,7 @@
 // Print the results list if a search was performed
     if ($_REQUEST['search']) {
     // Print the search name
-        echo '<p class="normal" align="center">',
+        echo '<p id="x_search_name">',
              ($_SESSION['search']['type'] == 'a'
                 ? t('Advanced Search')
                 : t('Search for:  $1', $_SESSION['search']['s'])
@@ -114,15 +115,15 @@
     // Display the results
 ?>
 
-<table width="100%" border="0" cellpadding="4" cellspacing="2" class="list small">
+<table id="search_results" class="list small" width="100%" border="0" cellpadding="4" cellspacing="2">
 <tr class="menu">
     <?php if (!empty($group_field)) echo "<td class=\"list\">&nbsp;</td>\n" ?>
-    <td><?php echo get_sort_link('title',       t('title')) ?></td>
-    <td><?php echo get_sort_link('category',    t('category')) ?></td>
-    <td><?php echo get_sort_link('description', t('description')) ?></td>
-    <td><?php echo get_sort_link('channum',     t('channum')) ?></td>
-    <td><?php echo get_sort_link('airdate',     t('airdate')) ?></td>
-    <td><?php echo get_sort_link('length',      t('length')) ?></td>
+    <th class="x-title"><?php       echo get_sort_link('title',       t('Title'))       ?></th>
+    <th class="x-category"><?php    echo get_sort_link('category',    t('Category'))    ?></th>
+    <th class="x-description"><?php echo get_sort_link('description', t('Description')) ?></th>
+    <th class="x-channum"><?php     echo get_sort_link('channum',     t('Channel'))     ?></th>
+    <th class="x-airdate"><?php     echo get_sort_link('airdate',     t('Airdate'))     ?></th>
+    <th class="x-length"><?php      echo get_sort_link('length',      t('Length'))      ?></th>
 </tr><?php
         $row = 0;
 
@@ -151,9 +152,9 @@
     </tr><?php
             }
     // Print the content
-    ?><tr class="<?php echo $show->class ?>" valign="top">
+    ?><tr class="<?php echo $show->css_class ?>" valign="top">
     <?php if (!empty($group_field)) echo "<td class=\"list\">&nbsp;</td>\n" ?>
-    <td class="<?php echo $show->class ?>"><?php
+    <td class="x-title <?php echo $show->css_class ?>"><?php
         if ($show->hdtv)
             echo '<span class="hdtv_icon">HD</span>';
         echo '<a href="', root, 'tv/detail/', $show->chanid, '/', $show->starttime, '">',
@@ -170,27 +171,27 @@
             if (strlen($show->starstring) > 0)
                 $info[] = $show->starstring;
             if (count($info) > 0)
-                echo '<br />(', implode(', ', $info), ')';
+                echo '<br>(', implode(', ', $info), ')';
         }
 
         ?></td>
-    <td><?php echo $show->category ?></td>
-    <td><?php echo $show->description ?></td>
-    <td><?php echo $show->channel->channum.' - '.$show->channel->name ?></td>
-    <td nowrap><?php
+    <td class="x-category"><?php    echo $show->category ?></td>
+    <td class="x-description"><?php echo $show->description ?></td>
+    <td class="x-channum"><?php     echo $show->channel->channum.' - '.$show->channel->name ?></td>
+    <td class="x-airdate"><?php
             echo '<a href="'.root.'tv/detail/'.$show->chanid.'/'.$show->starttime.'">'.
                 strftime($_SESSION['date_search'], $show->starttime) . '</a>';
             if ($show->extra_showings)
                 foreach ($show->extra_showings as $pair) {
                     list($chanid, $showtime) = $pair;
-                    echo '<br /><a href="', root, 'tv/detail/', $chanid, '/', $showtime, '" class="italic">',
+                    echo '<br><a href="', root, 'tv/detail/', $chanid, '/', $showtime, '" class="italic">',
                          strftime($_SESSION['date_search'] ,$showtime);
                     if ($chanid != $show->chanid)
                         echo ' (', $Channels[$chanid]->callsign, ')';
                     echo '</a>';
                 }
                 ?></td>
-    <td nowrap><?php echo nice_length($show->length) ?></td>
+    <td class="x-length"><?php echo nice_length($show->length) ?></td>
 </tr><?php
             $prev_group = $cur_group;
             $row++;
@@ -198,10 +199,9 @@
 ?>
 
 </table>
-</p>
+
 <?php
     }
 
 // Print the page footer
     require 'modules/_shared/tmpl/'.tmpl.'/footer.php';
-
