@@ -2,10 +2,10 @@
 /**
  * Welcome page description of the TV module.
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/tv/tmpl/default/welcome.php $
- * @date        $Date: 2006-01-24 21:41:36 -0600 (Tue, 24 Jan 2006) $
- * @version     $Revision: 8709 $
- * @author      $Author: xris $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/tv/tmpl/default/welcome.php $
+ * @date        $Date: 2008-02-10 02:36:08 +0000 (Sun, 10 Feb 2008) $
+ * @version     $Revision: 15879 $
+ * @author      $Author: kormoc $
  * @license     GPL
  *
  * @package     MythWeb
@@ -15,7 +15,7 @@
 
 // Open with a div and an image
     echo '<div id="info_tv">',
-         '<img src="', skin_url, '/img/tv.png" class="module_icon" />',
+         '<img src="', skin_url, 'img/tv.png" class="module_icon" alt="">',
 
 // Print a basic overview of what this module does
          t('welcome: tv'),
@@ -23,9 +23,9 @@
 // Next, print a list of possible subsectons
          '<ul>';
     foreach ($Modules['tv']['links'] as $link => $name) {
-        echo '    <li><a href="', root, 'tv/', $link, '">', html_entities($name), "</a></li>\n";
+        echo '    <li><a href="', root, $Modules['tv']['path'], '/', $link, '">', html_entities($name), "</a></li>\n";
     }
     echo '</ul>',
 
 // Close the div
-         "</div>\n";
\ No newline at end of file
+         "</div>\n";
