@@ -2,9 +2,9 @@
 /**
  * Channel detail
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/tv/tmpl/wap/channel.php $
- * @date        $Date: 2006-08-24 01:20:38 -0500 (Thu, 24 Aug 2006) $
- * @version     $Revision: 10936 $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/tv/tmpl/wap/channel.php $
+ * @date        $Date: 2007-12-31 20:38:38 +0000 (Mon, 31 Dec 2007) $
+ * @version     $Revision: 15274 $
  * @author      $Author: xris $
  * @license     GPL
  *
@@ -62,7 +62,8 @@
         foreach ($this_channel->programs as $show) {
     // Print the content
     ?>
-    <?php echo date('g:i A', $show->starttime) ?> - <?php echo date('g:i A', $show->endtime) ?><br />
+    <?php echo strftime($_SESSION['time_format'], $show->starttime) ?> - 
+    <?php echo strftime($_SESSION['time_format'], $show->endtime) ?><br />
 <?php
         echo '<a href="'.root.'tv/detail/'.$show->chanid.'/'.$show->starttime.'">'.$show->title.'</a><br />';
         if(strlen($show->subtitle))
