@@ -2,10 +2,10 @@
 /**
  * Program detail
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/tv/tmpl/wap/detail.php $
- * @date        $Date: 2006-06-24 14:03:10 -0500 (Sat, 24 Jun 2006) $
- * @version     $Revision: 10290 $
- * @author      $Author: xris $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/tv/tmpl/wap/detail.php $
+ * @date        $Date: 2008-02-07 07:07:52 +0000 (Thu, 07 Feb 2008) $
+ * @version     $Revision: 15821 $
+ * @author      $Author: kormoc $
  * @license     GPL
  *
  * @package     MythWeb
@@ -20,12 +20,12 @@
 // Print the page contents
 ?>
 <a href="<?php echo root ?>tv/channel/<?php echo $this_channel->chanid ?>" >
-<?php echo prefer_channum ? $this_channel->channum : $this_channel->callsign ?> &nbsp;
-<?php echo prefer_channum ? $this_channel->callsign : $this_channel->channum ?></a><br />
+<?php echo $_SESSION["prefer_channum"] ? $this_channel->channum : $this_channel->callsign ?> &nbsp;
+<?php echo $_SESSION["prefer_channum"] ? $this_channel->callsign : $this_channel->channum ?></a><br />
 
 <?php echo $program->title ?><BR>
 <?php echo date('D m/d/y', $program->starttime) ?><br />
-<?php echo date('g:i A', $program->starttime) ?> to <?php echo date('g:i A', $program->endtime) ?> (<?php echo (int)($program->length/60) ?> minutes)<BR>
+<?php echo strftime($_SESSION['time_format'], $program->starttime) ?> to <?php echo strftime($_SESSION['time_format'], $program->endtime) ?> (<?php echo (int)($program->length/60) ?> minutes)<BR>
                 <?php
                 if ($program->previouslyshown)
                     echo '(Rerun) ';
@@ -97,12 +97,12 @@
         <input type="checkbox" class="radio" name="inactive"<?php if ($schedule->inactive) echo ' CHECKED' ?> value="1" />
            <a><?php echo t('Inactive') ?></a><br />
         <?php echo t('No. of recordings to keep') ?>:
-        <input type="input" class="quantity" name="maxepisodes" value="<?php echo htmlentities($schedule->maxepisodes) ?>" size="2"/><br />
+        <input type="input" class="quantity" name="maxepisodes" value="<?php echo html_entities($schedule->maxepisodes) ?>" size="2"/><br />
         <?php echo t('Start Early') ?>:
-        <input type="input" class="quantity" name="startoffset" value="<?php echo htmlentities($schedule->startoffset) ?>" size="2"/>
+        <input type="input" class="quantity" name="startoffset" value="<?php echo html_entities($schedule->startoffset) ?>" size="2"/>
         <?php echo t('minutes') ?><br />
         <?php echo t('End Late') ?>:
-        <input type="input" class="quantity" name="endoffset" value="<?php echo htmlentities($schedule->endoffset) ?>" size="2"/>
+        <input type="input" class="quantity" name="endoffset" value="<?php echo html_entities($schedule->endoffset) ?>" size="2"/>
         <?php echo t('minutes') ?><br />
         <center><input type="submit" class="submit" name="save" value="Update Settings"></center>
         <br />
