@@ -2,10 +2,10 @@
 /**
  * Program listing
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/tv/tmpl/wap/list.php $
- * @date        $Date: 2006-08-31 00:24:50 -0500 (Thu, 31 Aug 2006) $
- * @version     $Revision: 11000 $
- * @author      $Author: xris $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/tv/tmpl/wap/list.php $
+ * @date        $Date: 2008-02-07 07:07:52 +0000 (Thu, 07 Feb 2008) $
+ * @version     $Revision: 15821 $
+ * @author      $Author: kormoc $
  * @license     GPL
  *
  * @package     MythWeb
@@ -93,8 +93,8 @@
     function print_channel($channel, $start_time, $end_time) {
         ?>
         <a href="<?php echo root ?>tv/channel/<?php echo $channel->chanid ?>/<?php echo date('Ymd', $start_time) ?>">
-        <?php echo prefer_channum ? $channel->channum : $chann->callsign ?>&nbsp;
-        <?php echo prefer_channum ? $channel->callsign : $channel->channum ?> </a>
+        <?php echo $_SESSION["prefer_channum"] ? $channel->channum : $chann->callsign ?>&nbsp;
+        <?php echo $_SESSION["prefer_channum"] ? $channel->callsign : $channel->channum ?> </a>
     	<a href="<?php echo root ?>tv/detail/<?php echo $channel->chanid ?>/<?php echo $channel->programs[0]->starttime ?>"><?php echo $channel->programs[0]->title ?></a><br />
         <?php
     }
