@@ -2,10 +2,10 @@
 /**
  * Recorded programs
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/tv/tmpl/wap/recorded.php $
- * @date        $Date: 2006-06-24 14:03:10 -0500 (Sat, 24 Jun 2006) $
- * @version     $Revision: 10290 $
- * @author      $Author: xris $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/tv/tmpl/wap/recorded.php $
+ * @date        $Date: 2008-02-06 03:53:09 +0000 (Wed, 06 Feb 2008) $
+ * @version     $Revision: 15799 $
+ * @author      $Author: kormoc $
  * @license     GPL
  *
  * @package     MythWeb
@@ -49,14 +49,14 @@
             echo "<b>".$show->subtitle."</b><br />";
         if(strlen($show->description)>1)
             echo $show->description."<br />";
-        echo date('D, M j,Y (g:i A)', $show->starttime)."<br />";
+        echo date('D, M j, Y', $show->starttime).' ('.strftime($_SESSION['time_format'], $show->starttime).")<br />";
         echo nice_length($show->length)." ".nice_filesize($show->filesize)."<br />";
 
         if ($show->endtime > time()) { ?>
             <font color="#FF0000">currently recording - </font>
 <?php   } ?>
-            <b></b><a id="delete_<?php echo $row ?>" href="<?php echo root ?>tv/recorded?delete=yes&file=<?php echo urlencode($show->filename) ?>">Delete </a></b>
-            <b></b><a id="delete_<?php echo $row ?>" href="<?php echo root ?>tv/recorded?delete=yes&file=<?php echo urlencode($show->filename) ?>&forget_old">Rerecord</a></b><br />
+            <b></b><a id="delete_<?php echo $row ?>" href="<?php echo root ?>tv/recorded?delete=yes&chanid=<?php echo $show->chanid ?>&starttime=<?php echo $show->recstartts ?>">Delete </a></b> 
+                <b></b><a id="delete_<?php echo $row ?>" href="<?php echo root ?>tv/recorded?delete=yes&chanid=<?php echo $show->chanid ?>&starttime=<?php echo $show->recstartts ?>&forget_old">Rerecord</a></b><br /> 
 <?php
         echo "<br />";
 
