@@ -2,9 +2,9 @@
 /**
  * Upcoming recordings
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/tv/tmpl/wap/upcoming.php $
- * @date        $Date: 2006-06-24 14:03:10 -0500 (Sat, 24 Jun 2006) $
- * @version     $Revision: 10290 $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/tv/tmpl/wap/upcoming.php $
+ * @date        $Date: 2007-12-31 20:38:38 +0000 (Mon, 31 Dec 2007) $
+ * @version     $Revision: 15274 $
  * @author      $Author: xris $
  * @license     GPL
  *
@@ -40,7 +40,7 @@
                 case 'Recording':
                 case 'WillRecord':
                     $rec_char   = $show->cardid;
-                    $class      = 'scheduled';
+                    $css_class  = 'scheduled';
                     $commands[] = '<a href="'.root.'tv/upcoming?dontrec=yes&'
                                   .$urlstr.'">'.t('Don\'t Record').'</a>';
                     // Offer to suppress any recordings that have enough info to do so.
@@ -53,7 +53,7 @@
                     break;
                 case 'PreviousRecording':
                     $rec_char   = 'P';
-                    $class      = 'duplicate';
+                    $css_class  = 'duplicate';
                     $commands[] = '<a href="'.root.'tv/upcoming?record=yes&'
                                   .$urlstr.'">'.t('Record This').'</a>';
                     $commands[] = '<a href="'.root.'tv/upcoming?'
@@ -62,7 +62,7 @@
                     break;
                 case 'CurrentRecording':
                     $rec_char   = 'R';
-                    $class      = 'duplicate';
+                    $css_class  = 'duplicate';
                     $commands[] = '<a href="'.root.'tv/upcoming?record=yes&'
                                   .$urlstr.'">'.t('Record This').'</a>';
                     $commands[] = '<a href="'.root.'tv/upcoming?'
@@ -71,11 +71,11 @@
                     break;
                 case 'Repeat':
                     $rec_char = 'r';
-                    $class    = 'duplicate';
+                    $css_class= 'duplicate';
                     break;
                 case 'EarlierShowing':
                     $rec_char = 'E';
-                    $class    = 'deactivated';
+                    $css_class= 'deactivated';
                     $commands[] = '<a href="'.root.'tv/upcoming?record=yes&'
                                   .$urlstr.'">'.t('Activate').'</a>';
                     $commands[] = '<a href="'.root.'tv/upcoming?default=yes&'
@@ -83,11 +83,11 @@
                     break;
                 case 'TooManyRecordings':
                     $rec_char = 'T';
-                    $class    = 'deactivated';
+                    $css_class= 'deactivated';
                     break;
                 case 'Cancelled':
                     $rec_char   = 'N';
-                    $class      = 'deactivated';
+                    $css_class  = 'deactivated';
                     $commands[] = '<a href="'.root.'tv/upcoming?record=yes&'
                                   .$urlstr.'">'.t('Activate').'</a>';
                     $commands[] = '<a href="'.root.'tv/upcoming?default=yes&'
@@ -101,7 +101,7 @@
                     //  need to modify this specific recstatus to avoid a conflict.
                     $rec_class = implode(' ', array(recstatus_class($show),
                                          'conflicting'));
-                    $class      = 'conflict';
+                    $css_class  = 'conflict';
                     $commands[] = '<a href="'.root.'tv/upcoming?record=yes&'
                                   .$urlstr.'">'.t('Record This').'</a>';
                     $commands[] = '<a href="'.root.'tv/upcoming?dontrec=yes&'
@@ -109,7 +109,7 @@
                     break;
                 case 'LaterShowing':
                     $rec_char = 'L';
-                    $class    = 'deactivated';
+                    $css_class= 'deactivated';
                     $commands[] = '<a href="'.root.'tv/upcoming?record=yes&'
                                   .$urlstr.'">'.t('Activate').'</a>';
                     $commands[] = '<a href="'.root.'tv/upcoming?default=yes&'
@@ -117,17 +117,17 @@
                     break;
                 case 'LowDiskSpace':
                     $rec_char   = 'K';
-                    $class      = 'deactivated';
+                    $css_class  = 'deactivated';
                     $commands[] = 'Not Enough Disk Space';
                     break;
                 case 'TunerBusy':
                     $rec_char   = 'B';
-                    $class      = 'deactivated';
+                    $css_class  = 'deactivated';
                     $commands[] = 'Tuner is busy';
                     break;
                 case 'Overlap':
                     $rec_char   = 'X';
-                    $class      = 'conflict';
+                    $css_class  = 'conflict';
                     $commands[] = '<a href="'.root.'tv/upcoming?record=yes&'
                                   .$urlstr.'">'.t('Record This').'</a>';
                     $commands[] = '<a href="'.root.'tv/upcoming?dontrec=yes&'
@@ -135,7 +135,7 @@
                     break;
                 case 'ManualOverride':
                     $rec_char   = 'X';
-                    $class      = 'deactivated';
+                    $css_class  = 'deactivated';
                     $commands[] = '<a href="'.root.'tv/upcoming?record=yes&'
                                   .$urlstr.'">'.t('Activate').'</a>';
                     $commands[] = '<a href="'.root.'tv/upcoming?default=yes&'
@@ -143,7 +143,7 @@
                     break;
                 case 'ForceRecord':
                     $rec_char   = 'F';
-                    $class      = 'scheduled';
+                    $css_class  = 'scheduled';
                     $commands[] = '<a href="'.root.'tv/upcoming?dontrec=yes&'
                                   .$urlstr.'">'.t('Don\'t Record').'</a>';
                     $commands[] = '<a href="'.root.'tv/upcoming?default=yes&'
@@ -152,7 +152,7 @@
                 default:
                     $rec_char   = '&nbsp;';
                     $rec_class  = '';
-                    $class      = 'deactivated';
+                    $css_class  = 'deactivated';
                     $commands[] = '<a href="'.root.'tv/upcoming?record=yes&'
                                   .$urlstr.'">'.t('Activate').'</a>';
                     $commands[] = '<a href="'.root.'tv/upcoming?dontrec=yes&'
@@ -160,7 +160,7 @@
                     break;
             }
 ?>
-    <tr class='<?php echo $class ?>'><td><?php echo $rec_char ?></td><td>
+    <tr class='<?php echo $css_class ?>'><td><?php echo $rec_char ?></td><td>
     <?php
         // Print a link to record this show
             echo '<a id="program_'.$program_id_counter.'_anchor" href="'.root.'tv/detail/'.$show->chanid.'/'.$show->starttime.'"'
@@ -171,7 +171,7 @@
     <tr><td></td><td>
       <?php echo $show->channel->name ?><br />
       <?php echo date('D, M j', $show->starttime) ?>
-      <?php echo date('(g:i A)', $show->starttime) ?> <?php echo nice_length($show->length) ?></td></tr>
+      <?php echo '('.strftime($_SESSION['time_format'], $show->starttime).')' ?> <?php echo nice_length($show->length) ?></td></tr>
       <tr><td></td><td>
 <?php
             echo implode(' | ', $commands);
