@@ -2,19 +2,20 @@
 /**
  * Welcome page description of the Weather module.
  *
- * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/weather/tmpl/default/welcome.php $
- * @date        $Date: 2005-12-13 01:23:18 -0600 (Tue, 13 Dec 2005) $
- * @version     $Revision: 8252 $
- * @author      $Author: xris $
+ * @url         $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/modules/weather/tmpl/default/welcome.php $
+ * @date        $Date: 2008-02-10 09:51:19 +0000 (Sun, 10 Feb 2008) $
+ * @version     $Revision: 15887 $
+ * @author      $Author: kormoc $
  * @license     GPL
  *
  * @package     MythWeb
+ * @subpackage  Weather
  *
 /**/
 
 // Open with a div and an image
     echo '<div id="info_weather" class="hidden">',
-         '<img src="', skin_url, '/img/weather.png" class="module_icon" />',
+         '<img src="', skin_url, '/img/weather.png" class="module_icon">',
 
 // Print a basic overview of what this module does
          t('welcome: weather'),
@@ -23,4 +24,4 @@
     ####
 
 // Close the div
-         "</div>\n";
\ No newline at end of file
+         "</div>\n";
