@@ -2,17 +2,25 @@
 #
 # This is the perl-based module handler.  It is the counterpart of mythweb.php
 #
-# @url       $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/mythweb.pl $
-# @date      $Date: 2006-04-08 16:21:52 -0500 (Sat, 08 Apr 2006) $
-# @version   $Revision: 9652 $
+# @url       $URL: http://svn.mythtv.org/svn/tags/release-0-21/mythplugins/mythweb/mythweb.pl $
+# @date      $Date: 2008-02-17 03:25:10 +0000 (Sun, 17 Feb 2008) $
+# @version   $Revision: 16105 $
 # @author    $Author: xris $
 #
 
 # Load some required modules
     use CGI qw/:standard/;
     use DBI;
+    use Cwd 'abs_path';
     use File::Basename;
 
+# pwd is / when running under mod_rewrite, so we should chdir to the script
+# directory for consistency
+    chdir dirname(abs_path($ENV{'SCRIPT_FILENAME'} or $0));
+
+# Don't forget to include the current directory in the search path.
+    substr($ENV{'PATH'}, 0, 0) = '.:';
+
 # Create a cgi object;
     our $cgi = new CGI;
 
@@ -33,6 +41,12 @@
         $ENV{'PATH'} .= ':'.$ENV{'include_path'};
     }
 
+# Work around a lighttpd bug:  http://trac.lighttpd.net/trac/ticket/420
+    foreach my $key (keys %ENV) {
+        next if ($key eq uc($key));
+        $ENV{$key} ||= $ENV{uc($key)};
+    }
+
 # Connect to the database
     END { $dbh->disconnect() if ($dbh); }
     our $dbh = DBI->connect("dbi:mysql:database=$ENV{'db_name'}:host=$ENV{'db_server'}",
